pub struct ServerHandle { /* private fields */ }Expand description
Handle to the server async task. The task is shutdown when the handle is dropped.
Implementations
Sourceimpl ServerHandle
impl ServerHandle
Sourcepub fn new(tx: Sender<ServerSetting>) -> Self
pub fn new(tx: Sender<ServerSetting>) -> Self
Construct a ServerHandle from its fields
This function is only required for the C bindings
Sourcepub async fn set_decode_level(
&mut self,
level: DecodeLevel,
) -> Result<(), Shutdown>
pub async fn set_decode_level( &mut self, level: DecodeLevel, ) -> Result<(), Shutdown>
Change the decoding level for future sessions and all active sessions